@@ -1,6 +1,6 @@
 /* Test file for mpfr_log10.
 
-Copyright 2001-2017 Free Software Foundation, Inc.
+Copyright 2001-2019 Free Software Foundation, Inc.
 Contributed by the AriC and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
@@ -17,12 +17,9 @@ License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+https://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
-#include <stdio.h>
-#include <stdlib.h>
-
 #include "mpfr-test.h"
 
 #ifdef CHECK_EXTERNAL
@@ -61,7 +58,7 @@ main (int argc, char *argv[])
 
   tests_start_mpfr ();
 
-  test_generic (2, 100, 20);
+  test_generic (MPFR_PREC_MIN, 100, 20);
 
   mpfr_init2 (x, 53);
   mpfr_init2 (y, 53);
